@@ -1230,7 +1230,7 @@ int exec_read_cmd(void *arg, unsigned int off, unsigned int len, unsigned int *d
 	struct ifreq	ifr;
 	char		msg[100];
 
-	memset(api_cmd.data, 0, WAN_MAX_DATA_SIZE);
+	memset(api_cmd.data, 0, WAN_MAX_CMD_DATA_SIZE);
 	memset(ifr.ifr_name, 0, WAN_IFNAME_SZ);
 	strncpy(ifr.ifr_name, aft->if_name, strlen(aft->if_name));
 	ifr.ifr_data = (char*)&api_cmd;
@@ -1266,7 +1266,7 @@ int exec_write_cmd(void *arg, unsigned int off, unsigned int len, unsigned int d
 	struct ifreq	ifr;
 	char		msg[100];
 
-	memset(api_cmd.data, 0, WAN_MAX_DATA_SIZE);
+	memset(api_cmd.data, 0, WAN_MAX_CMD_DATA_SIZE);
 	memset(ifr.ifr_name, 0, WAN_IFNAME_SZ);
 	strncpy(ifr.ifr_name, aft->if_name, strlen(aft->if_name));
 	ifr.ifr_data = (char*)&api_cmd;
@@ -1301,7 +1301,7 @@ int exec_bridge_read_cmd(void *arg, unsigned int off, unsigned int len, unsigned
 	struct ifreq	ifr;
 	char		msg[100];
 
-	memset(api_cmd.data, 0, WAN_MAX_DATA_SIZE);
+	memset(api_cmd.data, 0, WAN_MAX_CMD_DATA_SIZE);
 	memset(ifr.ifr_name, 0, WAN_IFNAME_SZ);
 	strncpy(ifr.ifr_name, aft->if_name, strlen(aft->if_name));
 	ifr.ifr_data = (char*)&api_cmd;
@@ -1337,7 +1337,7 @@ int exec_bridge_write_cmd(void *arg, unsigned int off, unsigned int len, unsigne
 	struct ifreq	ifr;
 	char		msg[100];
 
-	memset(api_cmd.data, 0, WAN_MAX_DATA_SIZE);
+	memset(api_cmd.data, 0, WAN_MAX_CMD_DATA_SIZE);
 	memset(ifr.ifr_name, 0, WAN_IFNAME_SZ);
 	strncpy(ifr.ifr_name, aft->if_name, strlen(aft->if_name));
 	ifr.ifr_data = (char*)&api_cmd;
